%This matlab file reads the data generated by the Analysis Sequences
%in the DemoModels and plots the comparisons between Coustyx results 
%and Analytical results.

%********************************************************************
%Compare results from coustyx and analytical solutions for an
%Cube Interior demo model with BCs: Pressure and Anechoic Termination

%********************************************************************
%Input:
%  Run the following Analysis Sequence in the Demo Model,
%  before running this matlab script. 
%   (1) RunValidation - FMM
%********************************************************************
resultsFMM = load('validation_results_fmm.txt');
%  Each *.txt results file has 5 columns, where
%    results(:,1) = xp (x coordinate of the point);
%                   field pt position (xp,0.5,0.5) 
%    results(:,2) = Real part of coustyx field point pressure
%    results(:,3) = Imaginary part of coustyx field point pressure
%    results(:,4) = Real part of analytical pressure
%    results(:,5) = Imaginary part of analytical pressure
%********************************************************************

%********************************************************************
%Output:
%  (1) plot 1: Plots comparisons between FMM and Analytical results
%  (2) plot 2: Plots comparisons between NonFMM and Analytical results
%********************************************************************

%Acoustic medium properties:
%  rho_o = medium density of air = 1.21 kg.m^3
%  c = speed of sound = 343 m/s
%  P0 = pressure excitation at (x=0) = 100 Pa
rho_o = 1.21;
c = 343;
P0 = 100;

%********************************************************************
%Plot FMM and Analytical results
%********************************************************************
figure;
plot(resultsFMM(:,1),resultsFMM(:,2)/P0,'r-',...
    resultsFMM(:,1),resultsFMM(:,4)/P0,'b.',...
    resultsFMM(:,1),resultsFMM(:,3)/P0,'m-',...
    resultsFMM(:,1),resultsFMM(:,5)/P0,'k.');
legend('Real Coustyx-FMM','Real Analytical','Imag Coustyx-FMM','Imag Analytical');
title('Field point pressures');
xlabel('xp (m)');
ylabel('P/p0');

matFMM = [resultsFMM(:,1) (abs(resultsFMM(:,2)+i*resultsFMM(:,3))/P0) (abs(resultsFMM(:,4)+i*resultsFMM(:,5))/P0)];





